@@ -29,11 +29,19 @@ import logging
 from .read_write_utils import check_read_write_params, read_from_file, write_to_file
 from .compare_utils import get_closest_match_from_list
 from .path_utils import makeAllDirs
-from .type_utils import make_list, convert_and_normalize_values
+from .list_utils import make_list
 from typing import List, Union, Dict, Any
 
 logging.basicConfig(level=logging.DEBUG, format='%(asctime)s - %(levelname)s - %(message)s')
 logger = logging.getLogger(__name__)
+def convert_and_normalize_values(values):
+    for value in values:
+        if isinstance(value, str):
+            yield value.lower()
+        elif isinstance(value, (int, float)):
+            yield value
+        else:
+            yield str(value).lower()
 def json_key_or_default(json_data,key,default_value):
     json_data = safe_json_loads(json_data)
     if not isinstance(json_data,dict) or (isinstance(json_data,dict) and key not in json_data):
@@ -96,8 +104,7 @@ def safe_write_to_json(file_path:str=None, data:(dict or list or str)=None,*args
         
             os.replace(temp_file_path, params[0])
 def safe_dump_to_file(data, file_path=None, ensure_ascii=False, indent=4, *args, **kwargs):
-    file_path, data = check_read_write_params(file_path=file_path, contents=data, *args, **kwargs)
-    if file_path and data is not None:
+    if file_path is not None and data is not None:
         try:
             if isinstance(data, (dict, list, tuple)):
                 with open(file_path, 'w', encoding='utf-8') as file:
@@ -106,7 +113,7 @@ def safe_dump_to_file(data, file_path=None, ensure_ascii=False, indent=4, *args,
                 with open(file_path, 'w', encoding='utf-8') as file:
                     file.write(str(data))
         except Exception as e:
-            logger.error(f"Error in safe_dump_to_file: {e}\nData: {file_path}, {data}")
+            logger.error(f"Error in safe_dump_to_file: {e}\nData: {file_path}")
     else:
         logger.error("file_path and data must be provided to safe_dump_to_file")
 
@@ -462,3 +469,29 @@ def update_dict_value(data, paths, new_value):
     # Update the value at the final key
     d[paths[-1]] = new_value
     return data
+def get_all_key_values(keys=None,dict_obj=None):
+    keys = keys or []
+    dict_obj = dict_obj or {}
+    new_dict_obj = {}
+    for key in keys:
+        values = dict_obj.get(key)
+        if values:
+            new_dict_obj[key]=values
+    return new_dict_obj
+
+def get_file_path(file_path):
+    if not os.path.isfile(file_path):
+        safe_dump_to_file(data={},file_path=file_path)
+    return file_path
+
+def get_json_data(file_path):
+    file_path = get_file_path(file_path)
+    data = safe_read_from_json(file_path)
+    return data
+
+def save_json_data(data,file_path):
+    data = data or {}
+    new_data = get_json_data(file_path)
+    new_data.update(data)
+    safe_dump_to_file(new_data,file_path)
+
