@@ -24,7 +24,7 @@ Version: 0.1.2
 """
 import os
 import platform
-from 
+from .read_write_utils import read_from_file
 def get_os_info():
     """
     Get Operating System Information
